@@ -58,6 +58,7 @@ extern int isservice(char *);
 extern int istrusted(char *);
 extern int isme(char *);
 extern int isop(struct channel *, char *);
+extern int isvoice(struct channel *, char *);
 extern int isvalidlogon(struct channel *, char *);
 extern int isopa(char *);
 extern int ishostless(char *);
@@ -86,6 +87,7 @@ extern int whichcommand(char *, int);
 extern int gettobek(struct channel *, char *);
 extern int checkforansi(struct channel *, char *, char *, char *);
 extern int checkforflood(struct channel *, char *, char *, char *);
+extern int checkfornickflood(struct channel *, char *, char *);
 extern int checkforbadword(struct channel *, char *, char *, char *);
 extern int checkforbadnick(struct channel *, char *, char *);
 extern int checkforautorejoin(struct channel *, char *, char *);
@@ -132,7 +134,7 @@ extern struct server *addnewserver(char *, int, int, int, int, int, char *);
 extern struct server *getserver(void);
 extern struct advert *addnewadvert(struct channel *, char *, char *);
 extern struct maskstruct *addnewmask(char *);
-extern struct maskstruct *addnewpermban(struct channel *, char *);
+extern struct maskstruct *addnewpermban(struct channel *, char *, char *, char *);
 extern struct maskstruct *addnewnickbk(struct channel *, char *, char *, char *);
 extern struct maskstruct *addnewwordbk(struct channel *, char *, char *, char *);
 extern struct maskstruct *addnewtrusted(char *);
@@ -144,6 +146,7 @@ extern struct maskstruct *editmask(struct maskstruct *, char *, char *);
 extern struct maskstruct *isnickbk(struct channel *, char *);
 extern struct maskstruct *iswordbk(struct channel *, char *);
 extern struct pubmsg *addnewpubmsg(struct channel *, time_t, char *, char *, char *);
+extern struct nickchange *addnewnickchange(struct channel *, char *);
 extern struct part *addnewpart(struct channel *, time_t, char *, char *);
 extern struct join *addnewjoin(struct channel *, time_t, char *, char *);
 extern struct topic *addnewtopic(struct channel *, char *, char *);
@@ -158,6 +161,7 @@ extern void sendadverts(struct channel *, char *, char *);
 extern void resetparts(struct channel *, char *, char *);
 extern void initpubmsgs(struct channel *);
 extern void freepubmsguser(char *, char *, char *);
+extern void freenickchanges(struct channel *, char *);
 extern void lockchan(struct channel *, char *, int, char *, char *);
 extern void unlockchan(struct channel *, char *, char *);
 extern void initchannel(struct channel *);
@@ -182,6 +186,7 @@ extern void banuser(struct channel *, time_t, char *);
 extern void unbanuser(struct channel *, time_t, char *);
 extern void kickuser(struct channel *, time_t, char *, char *);
 extern void sendreply(char *, int, int, int, char *);
+extern void sendwall(char *, struct channel *, int, char *);
 extern void sendchannelnotice(struct channel *, int, char *);
 extern void addcommand(struct channel *, char *, int, char *, char *, char *);
 extern void delcommand(struct channel *, char *, int, char *, char *, char *);
