@@ -34,6 +34,7 @@ int serverconnection(void);
 int registerconnection(void);
 int handleserverdata(void);
 int processtimeds(void);
+int processactions(struct timed *);
 void establishconnection(void);
 void reconnect(void);
 
@@ -63,7 +64,7 @@ void reconnect()
 		}
 		mystate->current_server->tx += strlen(stringbuffer);
 		close(mystate->sockfd);
-		mystate->current_server->registered = OER_REGISTERCONNECTION_STATUS_BEGIN;
+		memset(&mystate->current_server->registered, 0, sizeof(struct registered));
 		mystate->current_server->connected = 0;
 		mystate->current_server = NULL;
 		initall();
@@ -82,7 +83,7 @@ void reconnect()
 		oer_debug(OER_DEBUG_INFO, "main->current server is stoned, jumping to next one if available\n");
 #endif
 		close(mystate->sockfd);
-		mystate->current_server->registered = OER_REGISTERCONNECTION_STATUS_BEGIN;
+                memset(&mystate->current_server->registered, 0, sizeof(struct registered));
 		mystate->current_server->connected = 0;
 		mystate->current_server = NULL;
 		initall();
@@ -109,7 +110,7 @@ void reconnect()
 		oer_debug(OER_DEBUG_INFO, "reconnect->jumping to next server if available\n");
 #endif
 		close(mystate->sockfd);
-		mystate->current_server->registered = OER_REGISTERCONNECTION_STATUS_BEGIN;
+                memset(&mystate->current_server->registered, 0, sizeof(struct registered));
 		mystate->current_server->connected = 0;
 		mystate->current_server = NULL;
 		initall();
@@ -317,6 +318,7 @@ int registerconnection()
 {
 	char stringbuffer[WRITE_BUFFER_LENGTH + 1];
         char newuser[USERLEN + 1];
+	char prefixes[TINYSTRINGLEN + 1];
 	char *ptr;
 	struct passwd *pwd;
 #ifdef DEBUG
@@ -326,14 +328,23 @@ int registerconnection()
 	if(mystate->current_server == NULL) {
 		return OER_REGISTERCONNECTION_EVERYTHING_OK;
 	}
-	/* check if registered */
-	if(mystate->current_server->registered == OER_REGISTERCONNECTION_STATUS_DONE) {
+	/* check that all registration phases are complete */
+	if(mystate->current_server->registered.begin
+	   && mystate->current_server->registered.pass
+	   && mystate->current_server->registered.nick
+	   && mystate->current_server->registered.user
+	   && mystate->current_server->registered.done) {
 		return OER_REGISTERCONNECTION_EVERYTHING_OK;
 	}
-	if(mystate->current_server->registered == OER_REGISTERCONNECTION_STATUS_BEGIN) {
+	if(!mystate->current_server->registered.begin) {
+		/* BEGIN */
 #ifdef DEBUG
 		oer_debug(OER_DEBUG_INFO, "registerconnection->registering on the server\n");
 #endif
+		mystate->current_server->registered.begin = 1;
+	}
+	if(!mystate->current_server->registered.pass) {
+		/* PASS, OPTIONAL */
 		if(strlen(mystate->current_server->password)) {
 			snprintf(stringbuffer, WRITE_BUFFER_LENGTH, "PASS %s\n", mystate->current_server->password);
 #ifdef DEBUG
@@ -347,7 +358,11 @@ int registerconnection()
 			}
 			mystate->current_server->tx += strlen(stringbuffer);
 		}
-		snprintf(stringbuffer, WRITE_BUFFER_LENGTH, "NICK %s\n", (mystate->use_alt_nick) ? mystate->altnick : mystate->nick);
+                mystate->current_server->registered.pass = 1;
+	}
+        if(!mystate->current_server->registered.nick) {
+		/* NICK */
+		snprintf(stringbuffer, WRITE_BUFFER_LENGTH, "NICK %s\n", mystate->nick);
 #ifdef DEBUG
 		oer_debug(OER_DEBUG_INFO, "registerconnection->%s", stringbuffer);
 #endif
@@ -358,20 +373,19 @@ int registerconnection()
 			return OER_REGISTERCONNECTION_ERR_WRITE;
 		}
 		mystate->current_server->tx += strlen(stringbuffer);
-		mystate->current_server->registered = OER_REGISTERCONNECTION_STATUS_NICK;
-		return OER_REGISTERCONNECTION_EVERYTHING_OK;
+		mystate->current_server->registered.nick = 1;
 	}
-	if(mystate->current_server->registered == OER_REGISTERCONNECTION_STATUS_NICK) {
+	if(!mystate->current_server->registered.user) {
 		if(!mystate->customuser) {
 			if((pwd = getpwuid(getuid())) == NULL) {
 				return OER_REGISTERCONNECTION_ERR_GETPWUID;
 			}
 			strncpy(mystate->user, pwd->pw_name, USERLEN);
 		}
+		strncpy(prefixes, CONNECTION_STATE_PREFIXES, TINYSTRINGLEN);
 		ptr = mystate->user;
-		while(*ptr == '~' || *ptr == '^') {
-			/* server has prefixed our ident with ~ or ^,
-			   strip ~ or ^ before saving */
+		while(ptr && (index(prefixes, *ptr) != NULL)) {
+			/* strip the prefixes added by the server */
 			ptr++;
 		}
 		strncpy(newuser, ptr, USERLEN);
@@ -387,10 +401,9 @@ int registerconnection()
 			return OER_REGISTERCONNECTION_ERR_WRITE;
 		}
 		mystate->current_server->tx += strlen(stringbuffer);
-		mystate->current_server->registered = OER_REGISTERCONNECTION_STATUS_USER;
-		return OER_REGISTERCONNECTION_EVERYTHING_OK;
+		mystate->current_server->registered.user = 1;
 	}
-	return OER_REGISTERCONNECTION_STATUS_ERROR;
+	return OER_REGISTERCONNECTION_EVERYTHING_OK;
 }
 
 int handleserverdata()
@@ -463,7 +476,6 @@ int handleserverdata()
 int processtimeds()
 {
 	int got_timed;
-	int actions;
 	struct channel *this;
 	struct timed *t1;
 	struct timed *t2;
@@ -476,24 +488,24 @@ int processtimeds()
 		return OER_PROCESSTIMEDS_EVERYTHING_OK;
 	}
 	/* check if registered */
-	if(mystate->current_server->registered != OER_REGISTERCONNECTION_STATUS_DONE) {
-		return OER_PROCESSTIMEDS_EVERYTHING_OK;
-	}
+        if(!mystate->current_server->registered.done) {
+                return OER_REGISTERCONNECTION_EVERYTHING_OK;
+        }
 	if(mystate->netjoining) {
 		/* don't do any actions while net is joining */
 		return OER_PROCESSTIMEDS_EVERYTHING_OK;
 	}
-        for(t1 = mystate->timeds, actions = 0; t1 != NULL; t1 = t2) {
+	/* lower barrier */
+	if(mystate->last_action.ts < mystate->now && mystate->last_action.barrier) {
+		mystate->last_action.barrier--;
+	}
+        for(t1 = mystate->timeds; t1 != NULL; t1 = t2) {
 		if(t1->at > mystate->now) {
-			/* DO NOT REMOVE */
 			t2 = t1->next;
 			continue;
 		}
-		if(actions >= OER_ACTIONS_PER_MAINLOOP) {
-			return OER_PROCESSTIMEDS_EVERYTHING_OK;
-		}
-		/* limit kicks */
-		if(t1->type == OER_TIMED_TYPE_KICK && actions >= OER_KICKS_PER_MAINLOOP) {
+		/* check if timed can be scheduled now */
+		if(!processactions(t1)) {
 			return OER_PROCESSTIMEDS_EVERYTHING_OK;
 		}
 		got_timed = 0;
@@ -511,6 +523,7 @@ int processtimeds()
 			}
 			break;
 		case OER_TIMED_TYPE_NORMAL:
+		case OER_TIMED_TYPE_USERHOST:
 			snprintf(stringbuffer, WRITE_BUFFER_LENGTH, "%s\n", t1->command);
 			got_timed = 1;
 			break;
@@ -525,7 +538,6 @@ int processtimeds()
 #endif
 				return OER_PROCESSTIMEDS_ERR_WRITE;
 			}
-			actions++;
 			mystate->current_server->tx += strlen(stringbuffer);
 		}
 		t2 = t1->next;
@@ -534,3 +546,56 @@ int processtimeds()
 	}
 	return OER_PROCESSTIMEDS_EVERYTHING_OK;
 }
+
+int processactions(struct timed *t)
+{
+	struct channel *this;
+#ifdef DEBUG
+        oer_debug(OER_DEBUG_FLOOD, "processactions(\"%lu\")\n", t->at);
+        oer_debug(OER_DEBUG_INFO, "processactions->last action at %lu / delta %d / barrier %d\n", mystate->last_action.ts, (int) (mystate->now - mystate->last_action.ts), mystate->last_action.barrier);
+#endif
+	if(t->type != OER_TIMED_TYPE_KICK) {
+		if(t->prio == OER_TIMED_PRIORITY_CHANNEL_HANDLING ||
+		   t->prio == OER_TIMED_PRIORITY_CHANNEL_PROTECTION) {
+			if(mystate->now > mystate->last_action.ts || mystate->last_action.barrier < 5) {
+				mystate->last_action.ts = mystate->now;
+				mystate->last_action.barrier += 1 + (strlen(t->command) / 50);
+				return 1;
+			}
+		}
+	}
+	if(mystate->last_action.barrier) {
+		return 0;
+	}
+	mystate->last_action.ts = mystate->now;
+	switch(t->prio) {
+	case OER_TIMED_PRIORITY_WALL:
+		if((this = getchptr(t->channel)) == NULL) {
+			return 0;
+		}
+		/* this is necessary to avoid ERR_TARGETTOOFAST in ircu */
+		mystate->last_action.barrier += 5 + (this->nickcount / 2) + (strlen(t->command) / 50);
+		break;
+	case OER_TIMED_PRIORITY_FLOOD:
+		if(t->type == OER_TIMED_TYPE_USERHOST) {
+			mystate->last_action.barrier += 2 + (strlen(t->command) / 50);
+		} else {
+			mystate->last_action.barrier += 3 + (strlen(t->command) / 50);
+		}
+		break;
+	case OER_TIMED_PRIORITY_NOTICE:
+	case OER_TIMED_PRIORITY_PRIVMSG:
+		mystate->last_action.barrier += 2 + (strlen(t->command) / 50);
+		break;
+	case OER_TIMED_PRIORITY_NORMAL:
+	case OER_TIMED_PRIORITY_CHANNEL_HANDLING:
+	case OER_TIMED_PRIORITY_CHANNEL_PROTECTION:
+		if(t->type == OER_TIMED_TYPE_KICK) {
+			mystate->last_action.barrier += 2 + (strlen(t->command) / 50);
+		} else {
+			mystate->last_action.barrier += 1 + (strlen(t->command) / 50);
+		}
+		break;
+	}
+	return 1;
+}
