@@ -193,17 +193,9 @@ enum REGISTERCONNECTION_RETURN_VALUES {
 	OER_REGISTERCONNECTION_ERR_WRITE,
 	OER_REGISTERCONNECTION_ERR_HANDLESERVERDATA,
 	OER_REGISTERCONNECTION_ALREADY_REGISTERED,
+	OER_REGISTERCONNECTION_ERROR,
 	OER_REGISTERCONNECTION_EVERYTHING_OK
 };
-
-enum REGISTERCONNECTION_STATUS {
-	OER_REGISTERCONNECTION_STATUS_BEGIN,
-	OER_REGISTERCONNECTION_STATUS_NICK,
-	OER_REGISTERCONNECTION_STATUS_USER,
-	OER_REGISTERCONNECTION_STATUS_DONE,
-	OER_REGISTERCONNECTION_STATUS_ERROR
-};
-
 enum HANDLESERVERDATA_RETURN_VALUES {
 	OER_HANDLESERVERDATA_ERR_READ,
 	OER_HANDLESERVERDATA_ERR_NOTHING_READ,
@@ -234,11 +226,14 @@ enum OER_BAN_TYPES {
 enum OER_TIMED_TYPES {
 	OER_TIMED_TYPE_NORMAL = 1,
 	OER_TIMED_TYPE_KICK,
+	OER_TIMED_TYPE_USERHOST,
 	OER_TIMED_TYPE_INVALID
 };
 
 enum OER_TIMED_PRIORITIES {
-	OER_TIMED_PRIORITY_FLOOD = 1,
+	/* lowest priority first */
+	OER_TIMED_PRIORITY_WALL = 1,
+	OER_TIMED_PRIORITY_FLOOD,
 	OER_TIMED_PRIORITY_NOTICE,
 	OER_TIMED_PRIORITY_PRIVMSG,
 	OER_TIMED_PRIORITY_NORMAL,
@@ -263,8 +258,6 @@ enum OER_TIMED_PRIORITIES {
 /* multiple kicks aren't supported for backwards compatibility */
 #define OER_NICKS_PER_KICK 1
 #define OER_MAXTARGETS 20
-#define OER_TARGET_DELAY 120
-#define OER_WALL_DELAY 2
 #define OER_DEFAULT_DELIM "::"
 #define OER_DEFAULT_DELIM_LEN 2
 #define OER_QUOTE_MIN_LENGTH 10
@@ -283,6 +276,7 @@ enum OER_TIMED_PRIORITIES {
 #define OER_RECONNECT_DELAY 30
 #define OER_NETJOIN_DELAY 15
 #define OER_PUBMSGS 20
+#define OER_NICKCHANGES 20
 #define OER_TOPICS 10
 #define OER_SERVER_IS_STONED_FOR 300
 #define OER_LINENOISE_INTERVAL_MIN 1
@@ -311,6 +305,8 @@ enum OER_TIMED_PRIORITIES {
 #define PUBMSG_FLOOD_INTERVAL 60
 #define PUBMSG_FLOOD_REPEAT 3
 #define PUBMSG_FLOOD_REPEAT_EXPIRE 1800
+#define NICKFLOOD_EXPIRE 7200
+#define NICKFLOOD_CHANGES 5
 #define TXT_BUFFER 1024
 /* this is the ircd buffer size */
 #define IRCD_BUFFER_LENGTH 512
@@ -332,13 +328,15 @@ enum OER_TIMED_PRIORITIES {
 #define NICKLEN 20
 #define USERHOSTLEN HOSTLEN + USERLEN + NICKLEN + 2
 #define TOPICLEN 160
+#define TOPIC_SEPARATOR " | "
+#define CONNECTION_STATE_PREFIXES "^~+=-"
 #define OER_MAX_LIST_LINES 5
 #define OER_UNKNOWN "unknown"
 #define OER_HELP "For a complete command reference go to http://oer.equnet.org/help.html"
 #define DEFAULT_NICKBK_MESSAGE "prohibited nick"
 #define DEFAULT_WORDBK_MESSAGE "word ban-kick triggered, have a nice life..."
 #define OER_REALNAME "http://oer.equnet.org/help.html"
-#define OER_COPYRIGHT1 "oer version 1.0-47, Copyright (C) 2000-2001 EQU <equ@equnet.org>"
+#define OER_COPYRIGHT1 "oer version 1.0-48, Copyright (C) 2000-2001 EQU <equ@equnet.org>"
 #define OER_COPYRIGHT2 "oer comes with ABSOLUTELY NO WARRANTY; for details see the\n\
 GNU General Public License (COPYING) provided with this distribution.\n\
 This is free software, and you are welcome to redistribute it under\n\
@@ -350,6 +348,8 @@ struct floodvars {
 	int interval;
 	int lines;
 	int chars;
+	int nickflood_expire;
+	int nickflood_changes;
 };
 
 struct banvars {
@@ -455,6 +455,13 @@ struct pubmsg {
 	struct pubmsg *next;
 };
 
+struct nickchange {
+	time_t at;
+	char *userhost;
+	struct nickchange *prev;
+	struct nickchange *next;
+};
+
 struct join {
 	time_t at;
 	char *nick;
@@ -487,6 +494,19 @@ struct advert {
 	struct advert *next;
 };
 
+struct registered {
+	int begin;
+	int pass;
+	int nick;
+	int user;
+	int done;
+};
+
+struct last_action {
+	time_t ts;
+	unsigned int barrier;
+};
+
 struct server {
 	char serverhost[HOSTLEN + 1];
 	int serverport;
@@ -495,7 +515,7 @@ struct server {
 	int protected_ircops;
 	int used;
 	int connected;
-	int registered;
+	struct registered registered;
 	int stoned;
 	int linenoise;
 	int rx;
@@ -526,12 +546,12 @@ struct channel {
 	time_t rejoin_at;
 	time_t last_quote;
 	time_t join_ts;
-	time_t last_userhost;
 	FILE *seen;
 	FILE *last;
 	struct join *joins;
 	struct part *parts;
 	struct pubmsg *pubmsgs;
+	struct nickchange *nickchanges;
 	struct locked locked;
         struct floodvars floodvars;
         struct banvars banvars;
@@ -550,6 +570,8 @@ struct channel {
 
 struct state {
 	char progname[STRINGLEN + 1];
+	/* this is our current nick, might be temporarily set
+	   to getnick when attempting to change nick */
 	char nick[NICKLEN + 1];
 	char altnick[NICKLEN + 1];
 	char getnick[NICKLEN + 1];
@@ -563,7 +585,7 @@ struct state {
 	char prefix[MICROSTRINGLEN + 1];
 	int customuser;
 	int vhost;
-	int use_alt_nick;
+	int use_altnick;
 	int sockfd;
 	int loopforever;
 	int newnick;
@@ -574,7 +596,6 @@ struct state {
 	int reconnect;
 	int kickrs;
 	time_t now;
-	time_t last_actions;
 	time_t startup;
 	time_t postnj_checks_at;
 	time_t last_saved;
@@ -592,4 +613,5 @@ struct state {
 	struct server *servers;
 	struct server *current_server;
 	struct timed *timeds;
+	struct last_action last_action;
 };
