@@ -254,10 +254,6 @@ int main(int argc, char *argv[])
 		}
 		/* do some housekeeping */
 		processenv();	
-		/* check if it's safe to do some server actions */
-		if(mystate->now <= mystate->last_actions) {
-			continue;
-		}
 		/* convert all mmodes to timeds */
                 mmodes2timeds();
 		/* process timeds */
@@ -267,7 +263,6 @@ int main(int argc, char *argv[])
 			reconnect();
 			break;
 		}
-		mystate->last_actions = mystate->now;
 	}
 	exit(EXIT_SUCCESS);
 }
