@@ -46,6 +46,7 @@ void parseirc(char *serveroutput)
 	int restpos;
 	int nrestpos;
 	int tpos;
+	int do_syncbans;
 	char prefix[STRINGLEN + 1];
 	char command[TINYSTRINGLEN + 1];
 	char params[STRINGLEN + 1];
@@ -91,7 +92,7 @@ void parseirc(char *serveroutput)
 	restptr = serveroutput + ppos;
 	/* the rest of the line depends on the command/numeric */
 	if(!strcasecmp(command, "001")) {
-		mystate->current_server->registered = OER_REGISTERCONNECTION_STATUS_DONE;
+                mystate->current_server->registered.done = 1;
 		return;
 	}
 	if(!strcasecmp(command, "002")) {
@@ -293,6 +294,23 @@ void parseirc(char *serveroutput)
 #endif
 		return;
 	}
+	if(!strcasecmp(command, "405")) {
+#ifdef DEBUG
+		oer_debug(OER_DEBUG_INFO, "parseirc(405)->%s\n", restptr);
+#endif
+		/* ERR_TOOMANYCHANNELS */
+		restpos = 0;
+		if((restpos = parse(restptr, restpos, " ", channel, CHANLEN, 0)) < 0) {
+			return;
+		}
+		if((this = getchptr(channel)) == NULL) {
+			return;
+		}
+		/* reset joining flag, we will try again in OER_DELAY_BETWEEN_REJOINS seconds */
+		this->rejoin_at = mystate->now + OER_DELAY_BETWEEN_REJOINS;
+		this->joining = 0;
+		return;
+	}
 	if(!strcasecmp(command, "422")) {
 #ifdef DEBUG
 		oer_debug(OER_DEBUG_INFO, "parseirc(422)->%s\n", restptr);
@@ -305,21 +323,21 @@ void parseirc(char *serveroutput)
 			return;
 		}
 		/* check if we are still registering */
-                if(mystate->current_server->registered == OER_REGISTERCONNECTION_STATUS_NICK ||
-		   mystate->current_server->registered == OER_REGISTERCONNECTION_STATUS_USER) {
-			mystate->current_server->registered = OER_REGISTERCONNECTION_STATUS_BEGIN;
-			if(mystate->use_alt_nick) {
+                if(!mystate->current_server->registered.done) {
+			mystate->current_server->registered.nick = 0;
+			if(mystate->use_altnick) {
 #ifdef DEBUG
 				oer_debug(OER_DEBUG_INFO, "parseirc(%s)->both our primary and secondary nicknames are taken, generating a random nick\n", command);
 #endif
 				snprintf(mystate->nick, NICKLEN, "oer-%d", getrandom(9999));
-				mystate->use_alt_nick = 0;
-				return;
-			}
+				mystate->use_altnick = 0;
+			} else {
 #ifdef DEBUG
-			oer_debug(OER_DEBUG_INFO, "parseirc(%s)->our nickname %s is already in use, will try altnick %s\n", command, nick, mystate->altnick);
+				oer_debug(OER_DEBUG_INFO, "parseirc(%s)->our nickname %s is already in use, will try altnick %s\n", command, nick, mystate->altnick);
 #endif
-			mystate->use_alt_nick = 1;
+				strncpy(mystate->nick, mystate->altnick, NICKLEN);
+				mystate->use_altnick = 1;
+			}
 			return;
 		}
 		/* no, must be a nick change that failed */
@@ -336,21 +354,26 @@ void parseirc(char *serveroutput)
 		oer_debug(OER_DEBUG_INFO, "parseirc(%s)->%s\n", command, channel);
 #endif
 		if((this = getchptr(channel)) == NULL) {
-			/* no channel meaning nick is unavailable */
-			if(mystate->use_alt_nick) {
+			/* nick unavailable, check if we are still registering */
+			if(!mystate->current_server->registered.done) {
+				mystate->current_server->registered.nick = 0;
+				if(mystate->use_altnick) {
 #ifdef DEBUG
-				oer_debug(OER_DEBUG_INFO, "parseirc(%s)->both our primary and secondary nicknames are taken, generating a random nick\n", command);
+					oer_debug(OER_DEBUG_INFO, "parseirc(%s)->both our primary and secondary nicknames are taken, generating a random nick\n", command);
 #endif
-				snprintf(mystate->nick, NICKLEN, "oer-%d", getrandom(9999));
-				mystate->use_alt_nick = 0;
-				mystate->current_server->registered = OER_REGISTERCONNECTION_STATUS_BEGIN;
+					snprintf(mystate->nick, NICKLEN, "oer-%d", getrandom(9999));
+					mystate->use_altnick = 0;
+				} else {
+#ifdef DEBUG
+					oer_debug(OER_DEBUG_INFO, "parseirc(%s)->our nickname %s is already in use, will try altnick %s\n", command, nick, mystate->altnick);
+#endif
+					strncpy(mystate->nick, mystate->altnick, NICKLEN);
+					mystate->use_altnick = 1;
+				}
 				return;
 			}
-#ifdef DEBUG
-			oer_debug(OER_DEBUG_INFO, "parseirc(%s)->our nickname %s is already in use, will try altnick %s\n", command, mystate->nick, mystate->altnick);
-#endif
-			mystate->use_alt_nick = 1;
-			mystate->current_server->registered = OER_REGISTERCONNECTION_STATUS_BEGIN;
+			/* no, must be a nick change that failed */
+			strncpy(mystate->nick, params, NICKLEN);
 			return;
 		}
 		/* we got channel, reset joining flag */
@@ -374,7 +397,7 @@ void parseirc(char *serveroutput)
 #ifdef DEBUG
 		oer_debug(OER_DEBUG_INFO, "parseirc(464)->server reports bad password (%s)\n", (strlen(mystate->current_server->password)) ? mystate->current_server->password : "null");
 #endif
-		mystate->current_server->registered = OER_REGISTERCONNECTION_STATUS_BEGIN;
+                memset(&mystate->current_server->registered, 0, sizeof(struct registered));
 		return;
 	}
 	if(!strcasecmp(command, "467")) {
@@ -506,7 +529,7 @@ void parseirc(char *serveroutput)
 			if(!gettobek(this, nick) && checkforbadnick(this, nick, userhost)) {
 				changetobek(this, nick, 1);
 			}
-			if(!gettobek(this, nick) && haschanflags(this, "v") && hasuserflags(this, userhost, "v", "")) {
+			if(!gettobek(this, nick) && haschanflags(this, "v") && isvoice(this, userhost)) {
 				mmode_new(this, mystate->now, "+v", nick);
 			}
 			if(!gettobek(this, nick) && haschanflags(this, "O") && isopa(userhost)) {
@@ -546,7 +569,7 @@ void parseirc(char *serveroutput)
 		}
 		gettimeofday(&tv2, NULL);
 		snprintf(outstring3, HUGESTRINGLEN, "\"%s\" (c) %s", outstring2, nick2);
-		sendreply(channel, 1, 0, 0, outstring3);
+		sendreply(channel, 1, 0, OER_TIMED_PRIORITY_NORMAL, outstring3);
 		this->last_quote = mystate->now;
 		snprintf(outstring3, HUGESTRINGLEN, "%ld secs and %ld usecs", tv2.tv_sec - tv1.tv_sec, ABS(tv2.tv_usec - tv1.tv_usec));
 		if(tv2.tv_sec == tv1.tv_sec) {
@@ -656,8 +679,11 @@ void parseirc(char *serveroutput)
 			nickchange(this, nick, params + 1);
 			/* we change all channels but check only those that are needed (why?) */
 			if(isonchan(this, params + 1)) {
-				if(this->i_am_op && checkforbadnick(this, params + 1, userhost)) {
-					changetobek(this, params + 1, 1);
+				addnewnickchange(this, userhost);
+				if(this->i_am_op) {
+					if(checkforbadnick(this, params + 1, userhost) || checkfornickflood(this, params + 1, userhost)) {
+						changetobek(this, params + 1, 1);
+					}
 				} else {
 					/* this is a preventative measure. if a user tries
 					   to avoid getting kicked on !lock by changing nick,
@@ -765,6 +791,7 @@ void parseirc(char *serveroutput)
 		i = 0;
 		bans = 0;
 		deops = 0;
+		do_syncbans = 0;
 		while(1) {
 			switch((modetype = nthmode(mode, i))) {
 			case OER_NTHMODE_OP:
@@ -845,7 +872,7 @@ void parseirc(char *serveroutput)
 #ifdef DEBUG
 				oer_debug(OER_DEBUG_FLOOD, "parseirc(MODE)->OER_NTHMODE_BAN\n");
 #endif
-				snprintf(outstring, STRINGLEN, "%s!%s@%s", (mystate->use_alt_nick) ? mystate->altnick : mystate->nick, mystate->user, mystate->host);
+				snprintf(outstring, STRINGLEN, "%s!%s@%s", mystate->nick, mystate->user, mystate->host);
 				if(wild_match(target, outstring)) {
 #ifdef DEBUG
 					oer_debug(OER_DEBUG_INFO, "parseirc(MODE)->ban detected on me (%s)\n", target);
@@ -879,23 +906,24 @@ void parseirc(char *serveroutput)
 					oer_debug(OER_DEBUG_INFO, "parseirc(MODE)->%s on channel %s tried to remove the permban %s\n", temp_nick, channel, target);
 #endif
 					mmode_new(this, mystate->now, "+b", target);
+					do_syncbans = 1;
 				}
-				/* sync bans. if a user has set ban *@*.se and there is a
-				   permban *@*.swipnet.se, the latter has to be re-insert when
-				   the former is manually removed */
-				syncbans(this);
 				break;
 			case OER_NTHMODE_CHANMODE_WITHOUT_PARAMS:
 #ifdef DEBUG
 				oer_debug(OER_DEBUG_FLOOD, "parseirc(MODE)->OER_NTHMODE_CHANMODE_WITHOUT_PARAMS\n");
 #endif
-				this->setchanmode = 1;
+				if(!isme(temp_nick)) {
+					this->setchanmode = 1;
+				}
 				break;
 			case OER_NTHMODE_CHANMODE_WITH_PARAMS:
 #ifdef DEBUG
 				oer_debug(OER_DEBUG_FLOOD, "parseirc(MODE)->OER_NTHMODE_CHANMODE_WITH_PARAMS\n");
 #endif
-				this->setchanmode = 1;
+				if(!isme(temp_nick)) {
+					this->setchanmode = 1;
+				}
 				break;
 			}
 			if((deops > OER_MASSMODE_LIMIT) && (index(userhost, '@') != NULL) && !isme(temp_nick)) {
@@ -908,13 +936,19 @@ void parseirc(char *serveroutput)
 				}
 				if(this->i_am_op && haschanflags(this, "m") && !isserver(temp_nick)) {
 					mmode_new(this, mystate->now, "-o", temp_nick);
-					sendreply(temp_nick, 0, 3, 0, "do NOT deop >3 users at a time");
+					sendreply(temp_nick, 0, 3, OER_TIMED_PRIORITY_NORMAL, "do NOT deop >3 users at a time");
 					deops = 0;
 					bans = 0;
 				}
 			}
 			i++;
 		}
+		if(do_syncbans) {
+			/* sync bans. if a user has set ban *@*.se and there is a
+			   permban *@*.swipnet.se, the latter has to be re-insert when
+			   the former is manually removed */
+			syncbans(this);
+		}
 		return;
 	}
 	if(!strcasecmp(command, "TOPIC")) {
@@ -966,7 +1000,6 @@ void parsemsg(char *nick, char *userhost, char *target, char *message)
 	int ctcp;
 	int ppos;
 	int is_command;
-	char active_nick[NICKLEN + 1];
 	struct channel *this;
 #ifdef DEBUG
         oer_debug(OER_DEBUG_INFO, "parsemsg(\"%s\", \"%s\", \"%s\", \"%s\")\n", nick, userhost, target, message);
@@ -1024,10 +1057,6 @@ void parsemsg(char *nick, char *userhost, char *target, char *message)
 		parsecommand(target, nick, userhost, message);
 		return;
 	}
-	if(ctcp && ctcp != OER_WHICHCTCP_ACTION) {
-		/* only ACTIONS are sent to channel & checked */
-		return;
-	}
 	/* the message is a public message sent to a channel */
 	if((this = getchptr(target)) == NULL) {
 		return;
@@ -1053,13 +1082,9 @@ void parsemsg(char *nick, char *userhost, char *target, char *message)
 	/* check for command */
 	is_command = 0;
 	ppos = 0;
-	strncpy(active_nick, mystate->nick, NICKLEN);
-	if(mystate->use_alt_nick) {
-		strncpy(active_nick, mystate->altnick, NICKLEN);
-	}
-	if(!strncasecmp(message, active_nick, strlen(active_nick))) {
+	if(!strncasecmp(message, mystate->nick, strlen(mystate->nick))) {
 		is_command = 1;
-                ppos = strlen(active_nick);
+                ppos = strlen(mystate->nick);
                 if(isspace((int)message[ppos])) {
                         while(isspace((int)message[ppos])) {
                                 ppos++;
@@ -1246,7 +1271,7 @@ void parsecommand(char *target, char *nick, char *userhost, char *commandline)
 			return;
 		}
 		snprintf(outstring, WRITE_BUFFER_LENGTH, "deleted Topic #%d: %s", atoi(restptr), topic);
-		sendreply((tochan) ? this->name : nick, tochan, 0, 0, outstring);
+		sendreply((tochan) ? this->name : nick, tochan, 0, OER_TIMED_PRIORITY_NORMAL, outstring);
 		return;
 	case OER_WHICHCOMMAND_TOPIC_EDIT:
 #ifdef DEBUG
@@ -1906,6 +1931,8 @@ void parsecommand(char *target, char *nick, char *userhost, char *commandline)
 #ifdef DEBUG
 		oer_debug(OER_DEBUG_INFO, "parsecommand->HELP\n");
 #endif
+		/* may be NULL */
+		this = getchptr(channel);
 		proceed = (isopa(userhost)) ? 1 : 0;
 		for(that = mystate->channels; that != NULL && !proceed; that = that->next) {
 			if(haschanflags(that, "U") && !isatleastop(that, nick, userhost)) {
@@ -1915,11 +1942,16 @@ void parsecommand(char *target, char *nick, char *userhost, char *commandline)
 				proceed = 1;
 			}
 		}
+		/* check if message was sent to a channel and if it was
+		   is "s" flag set */
+		if(tochan && haschanflags(this, "s")) {
+			proceed = 1;
+		}
 		if(!proceed) {
 			return;
 		}
 		strncpy(outstring, OER_HELP, WRITE_BUFFER_LENGTH);
-		sendreply((tochan) ? channel : nick, tochan, 0, 0, outstring);
+		sendreply((tochan) ? channel : nick, tochan, 0, OER_TIMED_PRIORITY_NORMAL, outstring);
 		return;
 	case OER_WHICHCOMMAND_LIST:
 #ifdef DEBUG
@@ -2055,6 +2087,8 @@ void parsecommand(char *target, char *nick, char *userhost, char *commandline)
 #ifdef DEBUG
 		oer_debug(OER_DEBUG_INFO, "parsecommand->INFO\n");
 #endif
+		/* may be NULL */
+		this = getchptr(channel);
                 proceed = (isopa(userhost)) ? 1 : 0;
 		for(that = mystate->channels; that != NULL && !proceed; that = that->next) {
 			if(haschanflags(that, "U") && !isatleastop(that, nick, userhost)) {
@@ -2064,16 +2098,23 @@ void parsecommand(char *target, char *nick, char *userhost, char *commandline)
 				proceed = 1;
 			}
 		}
+		/* check if message was sent to a channel and if it was
+		   is "s" flag set */
+		if(tochan && haschanflags(this, "s")) {
+			proceed = 1;
+		}
 		if(!proceed) {
 			return;
 		}
 		snprintf(outstring, WRITE_BUFFER_LENGTH, "%s -- oer was written in March of 2000. This version of oer was compiled %s %s. The C source of this oer version consists of %d lines totalling %d bytes.", OER_COPYRIGHT1, __DATE__, __TIME__, SOURCE_LINES, SOURCE_CHARS);
-		sendreply((tochan) ? channel : nick, tochan, 0, 1, outstring);
+		sendreply((tochan) ? channel : nick, tochan, 0, OER_TIMED_PRIORITY_NORMAL, outstring);
 		return;
 	case OER_WHICHCOMMAND_UPTIME:
 #ifdef DEBUG
 		oer_debug(OER_DEBUG_INFO, "parsecommand->UPTIME\n");
 #endif
+		/* may be NULL */
+		this = getchptr(channel);
                 proceed = (isopa(userhost)) ? 1 : 0;
 		for(that = mystate->channels; that != NULL && !proceed; that = that->next) {
 			if(haschanflags(that, "U") && !isatleastop(that, nick, userhost)) {
@@ -2083,6 +2124,11 @@ void parsecommand(char *target, char *nick, char *userhost, char *commandline)
 				proceed = 1;
 			}
 		}
+		/* check if message was sent to a channel and if it was
+		   is "s" flag set */
+		if(tochan && haschanflags(this, "s")) {
+			proceed = 1;
+		}
 		if(!proceed) {
 			return;
 		}
@@ -2102,7 +2148,7 @@ void parsecommand(char *target, char *nick, char *userhost, char *commandline)
 #endif
 			strncat(outstring, outstring2, WRITE_BUFFER_LENGTH - strlen(outstring));
 		}
-		sendreply((tochan) ? channel : nick, tochan, 0, 1, outstring);
+		sendreply((tochan) ? channel : nick, tochan, 0, OER_TIMED_PRIORITY_NORMAL, outstring);
 		return;
 	case OER_WHICHCOMMAND_ACTION:
 #ifdef DEBUG
@@ -2119,7 +2165,7 @@ void parsecommand(char *target, char *nick, char *userhost, char *commandline)
                 }
 		if(strlen(restptr) > 0) {
 			snprintf(outstring, WRITE_BUFFER_LENGTH, "%cACTION %s%c", 1, restptr, 1);
-			sendreply(channel, 1, 0, 0, outstring);
+			sendreply(channel, 1, 0, OER_TIMED_PRIORITY_NORMAL, outstring);
 		}
 		return;
 	case OER_WHICHCOMMAND_SAY:
@@ -2136,7 +2182,7 @@ void parsecommand(char *target, char *nick, char *userhost, char *commandline)
                         return;
                 }
 		if(strlen(restptr) > 0) {
-			sendreply(channel, 1, 0, 0, restptr);
+			sendreply(channel, 1, 0, OER_TIMED_PRIORITY_NORMAL, restptr);
 		}
 		return;
 	case OER_WHICHCOMMAND_RAW:
@@ -2159,12 +2205,21 @@ void parsecommand(char *target, char *nick, char *userhost, char *commandline)
 		if((this = getchptr(channel)) == NULL) {
 			return;
 		}
-		if(haschanflags(this, "U") && !isatleastop(this, nick, userhost)) {
+                proceed = (isopa(userhost)) ? 1 : 0;
+		if(haschanflags(this, "U") && isatleastop(this, nick, userhost)) {
+			proceed = 1;
+		}
+                if(isatleastopnow(this, nick, userhost)) {
+			proceed = 1;
+                }
+		/* check if message was sent to a channel and if it was
+		   is "s" flag set */
+		if(tochan && haschanflags(this, "s")) {
+			proceed = 1;
+		}
+		if(!proceed) {
 			return;
 		}
-                if(!isatleastopnow(this, nick, userhost)) {
-                        return;
-                }
 		showlast(this, (tochan) ? this->name : nick, tochan, restptr);
 		return;
 	case OER_WHICHCOMMAND_QUOTE:
@@ -2174,23 +2229,32 @@ void parsecommand(char *target, char *nick, char *userhost, char *commandline)
 		if((this = getchptr(channel)) == NULL) {
 			return;
 		}
-		if(haschanflags(this, "U") && !isatleastop(this, nick, userhost)) {
+                proceed = (isopa(userhost)) ? 1 : 0;
+		if(haschanflags(this, "U") && isatleastop(this, nick, userhost)) {
+			proceed = 1;
+		}
+                if(isatleastopnow(this, nick, userhost)) {
+			proceed = 1;
+                }
+		/* check if message was sent to a channel and if it was
+		   is "s" flag set */
+		if(tochan && haschanflags(this, "s")) {
+			proceed = 1;
+		}
+		if(!proceed) {
 			return;
 		}
-                if(!isatleastopnow(this, nick, userhost)) {
-                        return;
-                }
 		if(!strlen(restptr)) {
 			return;
 		}
-		if(!(msgcount = getondiskmsgcount(this, restptr))) {
+		if((msgcount = getondiskmsgcount(this, restptr)) <= 0) {
 			return;
 		}
 		if(getrandommsg(this, restptr, NICKLEN, getrandom(msgcount), outstring, WRITE_BUFFER_LENGTH) < 0) {
 			return;
 		}
 		snprintf(outstring2, WRITE_BUFFER_LENGTH, "\"%s\" (c) %s", outstring, restptr);
-		sendreply((tochan) ? channel : nick, tochan, 0, 1, outstring2);
+		sendreply((tochan) ? channel : nick, tochan, 0, OER_TIMED_PRIORITY_NORMAL, outstring2);
 		return;
 	case OER_WHICHCOMMAND_SEEN:
 #ifdef DEBUG
@@ -2199,12 +2263,21 @@ void parsecommand(char *target, char *nick, char *userhost, char *commandline)
 		if((this = getchptr(channel)) == NULL) {
 			return;
 		}
-		if(haschanflags(this, "U") && !isatleastop(this, nick, userhost)) {
+                proceed = (isopa(userhost)) ? 1 : 0;
+		if(haschanflags(this, "U") && isatleastop(this, nick, userhost)) {
+			proceed = 1;
+		}
+                if(isatleastopnow(this, nick, userhost)) {
+			proceed = 1;
+                }
+		/* check if message was sent to a channel and if it was
+		   is "s" flag set */
+		if(tochan && haschanflags(this, "s")) {
+			proceed = 1;
+		}
+		if(!proceed) {
 			return;
 		}
-                if(!isatleastopnow(this, nick, userhost)) {
-                        return;
-                }
 		showseen(this, (tochan) ? channel : nick, tochan, restptr);
 		return;
 	case OER_WHICHCOMMAND_NSTATS:
@@ -2214,12 +2287,21 @@ void parsecommand(char *target, char *nick, char *userhost, char *commandline)
 		if((this = getchptr(channel)) == NULL) {
 			return;
 		}
-		if(haschanflags(this, "U") && !isatleastop(this, nick, userhost)) {
+                proceed = (isopa(userhost)) ? 1 : 0;
+		if(haschanflags(this, "U") && isatleastop(this, nick, userhost)) {
+			proceed = 1;
+		}
+                if(isatleastopnow(this, nick, userhost)) {
+			proceed = 1;
+                }
+		/* check if message was sent to a channel and if it was
+		   is "s" flag set */
+		if(tochan && haschanflags(this, "s")) {
+			proceed = 1;
+		}
+		if(!proceed) {
 			return;
 		}
-                if(!isatleastopnow(this, nick, userhost)) {
-                        return;
-                }
 		if(!strlen(restptr)) {
 			return;
 		}
@@ -2264,12 +2346,14 @@ void parsecommand(char *target, char *nick, char *userhost, char *commandline)
 			return;
 		}
 		snprintf(outstring, WRITE_BUFFER_LENGTH, "cloned channel %s to %s", channel, restptr);
-		sendreply((tochan) ? channel : nick, tochan, 0, 0, outstring);
+		sendreply((tochan) ? channel : nick, tochan, 0, OER_TIMED_PRIORITY_NORMAL, outstring);
 		return;
 	case OER_WHICHCOMMAND_SSTATS:
 #ifdef DEBUG
                 oer_debug(OER_DEBUG_INFO, "parsecommand->SSTATS\n");
 #endif
+		/* may be NULL */
+		this = getchptr(channel);
                 proceed = (isopa(userhost)) ? 1 : 0;
                 for(that = mystate->channels; that != NULL && !proceed; that = that->next) {
                         if(haschanflags(that, "U") && !isatleastop(that, nick, userhost)) {
@@ -2279,12 +2363,17 @@ void parsecommand(char *target, char *nick, char *userhost, char *commandline)
                                 proceed = 1;
                         }
                 }
+		/* check if message was sent to a channel and if it was
+		   is "s" flag set */
+		if(tochan && haschanflags(this, "s")) {
+			proceed = 1;
+		}
                 if(!proceed) {
                         return;
                 }
                 secondstostring(mystate->now - mystate->current_server->linkup, uptimestring, STRINGLEN);
                 snprintf(outstring, WRITE_BUFFER_LENGTH, "RX/TX bytes: %d/%d, link connected for %s", mystate->current_server->rx, mystate->current_server->tx, uptimestring);
-                sendreply((tochan) ? channel : nick, tochan, 0, 0, outstring);
+                sendreply((tochan) ? channel : nick, tochan, 0, OER_TIMED_PRIORITY_NORMAL, outstring);
                 return;
         case OER_WHICHCOMMAND_INVALID:
 #ifdef DEBUG
