@@ -124,8 +124,28 @@ if [ "$CREATECONF" = "Y" -o "$CREATECONF" = "y" ]; then
     $ECHO ""
     readln "Please specify bot admin handle [EQU] " "EQU"
     ADMIN=$ans
-    readln "Please specify bot admin flags [n] " "n"
+    readln "Please specify bot admin flags (n = unremovable, d = dynamic) [n] " "n"
     ADMINFLAGS=$ans
+    ISDYN=`$ECHO "$ADMINFLAGS" | sed 's/[0-9A-Za-ce-z]//g'`
+    if [ "$ISDYN" = "d" ]; then
+	stty -$ECHO
+	readln "Please specify your password [] " ""
+	PW=$ans
+	stty $ECHO
+	$ECHO ""
+	$ECHO ""
+	$ECHO -n "Crypting password ... "
+        CRYPT=`./mycrypt $PW`
+
+	if [ $RC -eq 1 ]; then
+		$ECHO "failed"
+		$ECHO ""
+	    exit 1
+	fi
+	
+	$ECHO "ok"
+	$ECHO ""
+    fi
     readln "Please specify bot admin hostmask [equ@*.equnet.org] " "equ@*.equnet.org"
     ADMINHOSTMASK=$ans
     
@@ -133,6 +153,9 @@ if [ "$CREATECONF" = "Y" -o "$CREATECONF" = "y" ]; then
     $ECHO -n "Creating configuration/oer.admins ... "
     $ECHO "admin::$ADMIN::$ADMINFLAGS" > configuration/oer.admins
     $ECHO "mask::$ADMIN::$ADMINHOSTMASK" >> configuration/oer.admins
+    if [ "$ISDYN" = "d" ]; then
+	$ECHO "password::$ADMIN::$CRYPT" >> configuration/oer.admins
+    fi
     
     RC=$?
     
@@ -159,9 +182,25 @@ if [ "$CREATECONF" = "Y" -o "$CREATECONF" = "y" ]; then
         SUCCESS=0
 	$ECHO "oer.admins exists, not copying over"
     fi
+    if [ ! -f $INSTALLTO/oer.kickreasons ]; then \
+	$INSTALL $PARAMS -m 644 sample-configuration/oer.kickreasons $INSTALLTO
+    else
+        SUCCESS=0
+	$ECHO "oer.kickreasons exists, not copying over"
+    fi
     if [ "$SUCCESS" = "1" ]; then
 	$ECHO ""
 	$ECHO "  oer configuration installed succesfully"
     fi
 fi
 exit 0
+
+
+
+
+
+
+
+
+
+
